@@ -1,13 +1,15 @@
 # Import Fusionbase
-from fusionbase.DataStream import DataStream
+from fusionbase.Fusionbase import Fusionbase
+import os
 
 # Create a new datastream
 # Provide your API Key and the Fusionbase API URI (usually: https://api.fusionbase.com/api/v1)
-data_stream = DataStream(auth={"api_key": "*** SECRET CREDENTIALS ***"},
+fusionbase = Fusionbase(auth={"api_key": os.getenv('FUSIONBASE_API_KEY')},
                       connection={"base_uri": "https://api.fusionbase.com/api/v1"})
 
 
-data_stream_key = 28654971
+data_stream_key = "28654971"
+data_stream = fusionbase.get_datastream(key=data_stream_key)
 
 # Print a nice table containing the meta data of the stream
-data_stream.pretty_meta_data(key=data_stream_key)
\ No newline at end of file
+data_stream.pretty_meta_data()
\ No newline at end of file
